API Version: 4.1
Library Version: 2.44.1
enum WebKit2.AutoplayPolicy
Enum values used to specify autoplay policies.
WEBKIT_AUTOPLAY_ALLOW
Do not restrict autoplay.
WEBKIT_AUTOPLAY_ALLOW_WITHOUT_SOUND
Allow videos to autoplay if they have no audio track, or if their audio track is muted.
WEBKIT_AUTOPLAY_DENY
Never allow autoplay.
Content